[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mistat)](https://pypi.org/project/mistat/)
![Python](https://github.com/gedeck/mistat/actions/workflows/build.yml/badge.svg)

# Modern Industrial Statistics: with applications in Python

Collection of utility functions



